@@ -43,7 +43,7 @@ if(process.argv.length === 2){
 }
 
 //if command is not part of available command display general help
-if(process.argv.length > 2 && typeof program._events[process.argv[2]] === "undefined"){
+if(process.argv.length > 2 && typeof program._events['command:'+process.argv[2]] === "undefined"){
   program.error({message:"Unknown command \""+process.argv[2]+"\""});
   program.outputHelp()
   process.exit(1)
